COMPMID-674 - Create Google InceptionV3 example

Change-Id: I389e0d4104b7dde60b7cdd612a83f3328517e44c
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/115804
Tested-by: Jenkins <bsgcomp@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/core/SubTensorInfo.h b/arm_compute/core/SubTensorInfo.h
index 7c464c0..67574f1 100644
--- a/arm_compute/core/SubTensorInfo.h
+++ b/arm_compute/core/SubTensorInfo.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017 ARM Limited.
+ * Copyright (c) 2017-2018 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -46,12 +46,13 @@
     SubTensorInfo();
     /** Default constructor
      *
      * @param[in] parent       Metadata of parent tensor.
      * @param[in] tensor_shape Tensor shape. Shape must fit inside parent's shape.
      *                         X and Y dimensions must match the parent's ones.
      * @param[in] coords       Coordinates of starting element inside parent tensor.
      */
-    SubTensorInfo(ITensorInfo *parent, TensorShape tensor_shape, Coordinates coords);
+    SubTensorInfo(ITensorInfo *parent, TensorShape tensor_shape, Coordinates coords, bool extend_parent = false);
     /** Default destructor */
     ~SubTensorInfo() = default;
     /** Allow instances of this class to be copy constructed */
@@ -216,6 +217,7 @@
     TensorShape  _tensor_shape;
     Coordinates  _coords;
     ValidRegion  _valid_region;
+    bool         _extend_parent;
 };
 }
 #endif /*__ARM_COMPUTE_SUBTENSORINFO_H__ */
@@ -46,12 +46,13 @@
     /** Default constructor
      *
-     * @param[in] parent       Metadata of parent tensor.
-     * @param[in] tensor_shape Tensor shape. Shape must fit inside parent's shape.
-     *                         X and Y dimensions must match the parent's ones.
-     * @param[in] coords       Coordinates of starting element inside parent tensor.
+     * @param[in] parent        Metadata of parent tensor.
+     * @param[in] tensor_shape  Tensor shape. Shape must fit inside parent's shape.
+     *                          X and Y dimensions must match the parent's ones.
+     * @param[in] coords        Coordinates of starting element inside parent tensor.
+     * @param[in] extend_parent (Optional) Extend parent with subtensor shape if subtensor indexes out of bounds
      */